@@ -1635,7 +1635,7 @@ void FolderModel::createActions()
     connect(restoreFromTrash, &QAction::triggered, this, &FolderModel::restoreSelectedFromTrash);
 
     QAction *actOpen = new QAction(QIcon::fromTheme(QStringLiteral("window-new")), i18n("&Open"), this);
-    connect(actOpen, &QAction::triggered, this, &FolderModel::openSelected);
+    connect(actOpen, &QAction::triggered, this, &FolderModel::runSelected);
 
     m_actionCollection.addAction(QStringLiteral("open"), actOpen);
     m_actionCollection.addAction(QStringLiteral("cut"), cut);
@@ -1708,7 +1708,7 @@ void FolderModel::updateActions()
 
     if (m_newMenu) {
         m_newMenu->checkUpToDate();
-        m_newMenu->setPopupFiles(QList<QUrl>() << m_dirModel->dirLister()->url());
+        m_newMenu->setWorkingDirectory(m_dirModel->dirLister()->url());
         // we need to set here as well, when the menu is shown via AppletInterface::eventFilter
         m_menuPosition = QCursor::pos();
 
@@ -2078,20 +2078,6 @@ void FolderModel::deleteSelected()
     }
 }
 
-void FolderModel::openSelected()
-{
-    if (!m_selectionModel->hasSelection()) {
-        return;
-    }
-
-    const QList<QUrl> urls = selectedUrls();
-    for (const QUrl &url : urls) {
-        auto job = new KIO::OpenUrlJob(url);
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
-        job->start();
-    }
-}
-
 void FolderModel::undo()
 {
     if (QAction *action = m_actionCollection.action(QStringLiteral("undo"))) {
@@ -2139,7 +2125,7 @@ void FolderModel::undoTextChanged(const QString &text)
 
 void FolderModel::createFolder()
 {
-    m_newMenu->setPopupFiles(QList<QUrl>() << m_dirModel->dirLister()->url());
+    m_newMenu->setWorkingDirectory(m_dirModel->dirLister()->url());
     m_newMenu->createDirectory();
 }
 
