@@ -18,8 +18,6 @@
 #include <kglobalaccel_component_interface.h>
 #include <kglobalaccel_interface.h>
 
-#include <kglobalaccel_version.h>
-
 #include "kcmkeys_debug.h"
 
 static QStringList buildActionId(const QString &componentUnique, const QString &componentFriendly, const QString &actionUnique, const QString &actionFriendly)
@@ -178,11 +176,7 @@ void GlobalAccelModel::save()
                     keys.append(key);
                 }
                 qCDebug(KCMKEYS) << "Saving" << actionId << action.activeShortcuts << keys;
-#if KGLOBALACCEL_VERSION >= QT_VERSION_CHECK(5, 90, 0)
                 auto reply = m_globalAccelInterface->setForeignShortcutKeys(actionId, keys);
-#else
-                auto reply = m_globalAccelInterface->setForeignShortcut(actionId, keys);
-#endif
                 reply.waitForFinished();
                 if (!reply.isValid()) {
                     qCCritical(KCMKEYS) << "Error while saving";
@@ -254,8 +248,23 @@ void GlobalAccelModel::importConfig(const KConfigBase &config)
 
 void GlobalAccelModel::addApplication(const QString &desktopFileName, const QString &displayName)
 {
+    if (desktopFileName.isEmpty()) {
+        qCWarning(KCMKEYS()) << "Tried to add empty application" << displayName;
+        return;
+    }
+
+    // In certain cases, we can get an absolute file name as desktopFileName,
+    // but the rest of the code assumes we're using a relative filename. So in
+    // that case, strip the paths off and only use the file name.
+    QFileInfo info(desktopFileName);
+
+    QString desktopName = desktopFileName;
+    if (info.isAbsolute()) {
+        desktopName = info.fileName();
+    }
+
     // Register a dummy action to trigger kglobalaccel to parse the desktop file
-    QStringList actionId = buildActionId(desktopFileName, displayName, QString(), QString());
+    QStringList actionId = buildActionId(desktopName, displayName, QString(), QString());
     m_globalAccelInterface->doRegister(actionId);
     m_globalAccelInterface->unRegister(actionId);
     QCollator collator;
@@ -264,12 +273,12 @@ void GlobalAccelModel::addApplication(const QString &desktopFileName, const QStr
     auto pos = std::lower_bound(m_components.begin(), m_components.end(), displayName, [&](const Component &c, const QString &name) {
         return c.type != i18n("System Services") && collator.compare(c.displayName, name) < 0;
     });
-    auto watcher = new QDBusPendingCallWatcher(m_globalAccelInterface->getComponent(desktopFileName));
+    auto watcher = new QDBusPendingCallWatcher(m_globalAccelInterface->getComponent(desktopName));
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] {
         QDBusPendingReply<QDBusObjectPath> reply = *watcher;
         watcher->deleteLater();
         if (!reply.isValid()) {
-            genericErrorOccured(QStringLiteral("Error while calling objectPath of added application") + desktopFileName, reply.error());
+            genericErrorOccured(QStringLiteral("Error while calling objectPath of added application") + desktopName, reply.error());
             return;
         }
         KGlobalAccelComponentInterface component(m_globalAccelInterface->service(), reply.value().path(), m_globalAccelInterface->connection());
@@ -278,7 +287,7 @@ void GlobalAccelModel::addApplication(const QString &desktopFileName, const QStr
             QDBusPendingReply<QList<KGlobalShortcutInfo>> infoReply = *infoWatcher;
             infoWatcher->deleteLater();
             if (!infoReply.isValid()) {
-                genericErrorOccured(QStringLiteral("Error while calling allShortCutInfos on new component") + desktopFileName, infoReply.error());
+                genericErrorOccured(QStringLiteral("Error while calling allShortCutInfos on new component") + desktopName, infoReply.error());
                 return;
             }
             if (infoReply.value().isEmpty()) {
@@ -304,7 +313,7 @@ void GlobalAccelModel::removeComponent(const Component &component)
         return;
     }
     KGlobalAccelComponentInterface componentInterface(m_globalAccelInterface->service(), componentReply.value().path(), m_globalAccelInterface->connection());
-    qCDebug(KCMKEYS) << "Cleaning up component at" << componentReply.value();
+    qCDebug(KCMKEYS) << "Cleaning up component at" << componentReply.value().path();
     auto cleanUpReply = componentInterface.cleanUp();
     cleanUpReply.waitForFinished();
     if (!cleanUpReply.isValid()) {
