@@ -9,7 +9,11 @@
 
 #include <QSocketNotifier>
 #include <QVector>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#endif
 
 #include <xcb/record.h>
 #include <xcb/xcb.h>
